@@ -8,6 +8,8 @@ import logging
 import os
 import re
 
+test_injection = """a0.9i0a9deienatd"""
+
 
 class Injections(object):
     """
@@ -21,8 +23,8 @@ class Injections(object):
     inject_dict = {}  # dictionary holding the injection object
     clear_dict = set()  # list holding the filenames to clear injection from
 
-    def __init__(self, wrapper):
-        self.logger = logging.getLogger('sprinter')
+    def __init__(self, wrapper, logger='sprinter'):
+        self.logger = logging.getLogger(logger)
         self.wrapper = wrapper
 
     def inject(self, filename, content):
@@ -68,7 +70,7 @@ class Injections(object):
         install_file.write(content)
         install_file.close()
 
-    def __clear(install_filename, wrapper):
+    def __clear(self, install_filename, wrapper):
         """
         Inject inject_string into a file, wrapped with
         #SPRINTER_{{NAMESPACE}} comments if condition lambda is not
@@ -79,8 +81,8 @@ class Injections(object):
         if not os.path.exists(install_filename):
             open(install_filename, "w+").close()
         install_file = open(install_filename, "r+")
-        content = re.sub("%s.*%s" % (wrapper, wrapper),
-                         "", install_file.read(), re.DOTALL)
+        wrapper_match = re.compile("\n%s.*%s" % (wrapper, wrapper), re.DOTALL)
+        content = wrapper_match.sub("", install_file.read())
         install_file.close()
         install_file = open(install_filename, "w+")
         install_file.write(content)
