@@ -162,6 +162,7 @@ class Config(object):
         """
         self.source = source
         self.target = target
+        self.source_location = self.target.source() or self.source.source()
         # store raws to use on write
         self.source_raw = source
         self.target_raw = target
@@ -286,6 +287,8 @@ class Config(object):
             if k not in self.temporary_sections:
                 self.target.set('config', k, v)
         self.target.set('config', 'namespace', self.namespace)
+        if self.source_location:
+            self.target.set('config','source', self.source_location)
         self.target.write(file_handle)
 
     def get_config(self, param_name, default=None, secret=False):
